@@ -9,7 +9,6 @@ use Class::Accessor::Fast;
 
 our @ISA = qw(Exporter Class::Accessor::Fast);
 
-our $VERSION = '0.05';
 
 require XSLoader;
 XSLoader::load('SkypeAPI::Win', $VERSION);
@@ -81,28 +80,3 @@ sub DESTROY {
 
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
-
-=head1 NAME
-
-SkypeAPI::Win - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use SkypeAPI::Win;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for SkypeAPI::Win, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head2 EXPORT
-
-None by default.
-
-
-
